@@ -1,4 +1,3 @@
-from concurrent.futures import ThreadPoolExecutor
 from functools import wraps
 from re import compile
 from threading import RLock
@@ -48,7 +47,6 @@ class CPDLC:
         _network (Optional[Network]): Hoppie ACARS network
         _client (httpx.Client): httpx client
         _state_lock (threading.RLock): global lock
-        _thread_pool (concurrent.futures.ThreadPoolExecutor) : thread pool
 
     Examples:
         # Create CPDLC client instance\n
@@ -97,11 +95,9 @@ class CPDLC:
         cpdlc.cpdlc_logout()\n
     """
 
-    def __init__(self, max_workers: int = 8):
+    def __init__(self):
         """
         Constructor for CPDLC class
-        Args:
-            max_workers (int): Maximum number of threads
         """
         logger.trace("CPDLC client initializing")
         self._service_initialization = False
@@ -122,9 +118,7 @@ class CPDLC:
         self._network: Network = Network.UNKNOWN
         self._state_lock = RLock()
         self._client: Optional[Client] = None
-        self._thread_pool = ThreadPoolExecutor(max_workers=max_workers)
         logger.trace("CPDLC client initialized")
-        self._thread_pool.submit(lambda: self.client)
 
     def __del__(self):
         if hasattr(self, '_client') and self._client:
@@ -293,28 +287,17 @@ class CPDLC:
             raise ParameterError("Callsign is required")
         if self._login_code is None:
             raise ParameterError("Login code is required")
-
-        def check_connection():
-            if not self._ping_station():
-                logger.error(f"CPDLC init failed. Connection error")
-                raise InitializationError()
-            logger.debug(f"CPDLC init complete. Connection OK")
-
-        def check_service_level():
-            if self._email is None:
-                logger.trace(f"Half service provide due to missing email")
-                self._service_level = ServiceLevel.HALF
-            else:
-                logger.trace(f"Full service provided")
-                self._service_level = ServiceLevel.FULL
-                self._network = self.get_network()
-
-        result_1 = self._thread_pool.submit(check_connection)
-        result_2 = self._thread_pool.submit(check_service_level)
-
-        result_1.result()
-        result_2.result()
-
+        if not self._ping_station():
+            logger.error(f"CPDLC init failed. Connection error")
+            raise InitializationError()
+        logger.debug(f"CPDLC init complete. Connection OK")
+        if self._email is None:
+            logger.trace(f"Half service provide due to missing email")
+            self._service_level = ServiceLevel.HALF
+        else:
+            logger.trace(f"Full service provided")
+            self._service_level = ServiceLevel.FULL
+            self._network = self.get_network()
         self.start_poller()
         self._service_initialization = True
 
@@ -364,17 +347,13 @@ class CPDLC:
         Args:
             message (str): message
         """
-
-        def execute(fn: Callable[[AcarsMessage], None]) -> None:
-            try:
-                logger.trace(f"Callback executed: {callback.__name__}")
-                fn(message)
-            except Exception as e:
-                logger.error(f"Exception occurred while calling callback: {e}")
-
         logger.trace(f"Message received : {message}")
         for callback in self._message_receiver_callbacks:
-            self._thread_pool.submit(execute, callback)
+            try:
+                logger.trace(f"Callback executed: {callback.__name__}")
+                callback(message)
+            except Exception as e:
+                logger.error(f"Exception occurred while calling callback: {e}")
 
     def listen_message_sender(self):
         """
@@ -401,17 +380,13 @@ class CPDLC:
             to (str): message send to
             message (str): message
         """
-
-        def execute(fn: Callable[[str, str], None]) -> None:
-            try:
-                logger.trace(f"Callback executed: {callback.__name__}")
-                fn(to, message)
-            except Exception as e:
-                logger.error(f"Exception occurred while calling callback: {e}")
-
         logger.trace(f"Message send to {to}: {message}")
         for callback in self._message_sender_callbacks:
-            self._thread_pool.submit(execute, callback)
+            try:
+                logger.trace(f"Callback executed: {callback.__name__}")
+                callback(to, message)
+            except Exception as e:
+                logger.error(f"Exception occurred while calling callback: {e}")
 
     # Decorators
 
@@ -577,11 +552,15 @@ class CPDLC:
         if element is None:
             logger.error(f"Change network failed, wrong response")
             raise ResponseParserError()
-        changed_network = element.text.split(" ")[-1].removesuffix(".")
-        if changed_network != new_network.value:
-            logger.error(f"Change network failed. Expected {new_network.value}, got {changed_network}")
+        element = soup.find("select", attrs={"name": "network"})
+        if element is None:
+            logger.error(f"Login code or email is invalid, please check login code or email")
+            raise LoginError()
+        selected = element.find("option", attrs={"selected": ""})
+        if selected.text != new_network.value:
+            logger.error(f"Change network failed. Expected {new_network.value}, got {selected.text}")
             raise NetworkSwitchError(self._network, new_network)
-        self._network = new_network
+        self._network = Network(selected.text)
         logger.debug(f"Network changed to {new_network.value}")
         return True
 
